//package org.dromara.system.controller.room;
//
//import java.util.List;
//
//import lombok.RequiredArgsConstructor;
//import jakarta.servlet.http.HttpServletResponse;
//import jakarta.validation.constraints.*;
//import cn.dev33.satoken.annotation.SaCheckPermission;
//import org.springframework.web.bind.annotation.*;
//import org.springframework.validation.annotation.Validated;
//import org.dromara.common.idempotent.annotation.RepeatSubmit;
//import org.dromara.common.log.annotation.Log;
//import org.dromara.common.web.core.BaseController;
//import org.dromara.common.mybatis.core.page.PageQuery;
//import org.dromara.common.core.domain.R;
//import org.dromara.common.core.validate.AddGroup;
//import org.dromara.common.core.validate.EditGroup;
//import org.dromara.common.log.enums.BusinessType;
//import org.dromara.common.excel.utils.ExcelUtil;
//import org.dromara.system.domain.vo.TypeHotVo;
//import org.dromara.system.domain.bo.TypeHotBo;
//import org.dromara.system.service.ITypeHotService;
//import org.dromara.common.mybatis.core.page.TableDataInfo;
//
///**
// * 【请填写功能名称】
// *
// * @author Lion Li
// * @date 2024-12-16
// */
//@Validated
//@RequiredArgsConstructor
//@RestController
//@RequestMapping("/system/hot")
//public class TypeHotController extends BaseController {
//
//    private final ITypeHotService typeHotService;
//
//    /**
//     * 查询【请填写功能名称】列表
//     */
//    @SaCheckPermission("system:hot:list")
//    @GetMapping("/list")
//    public TableDataInfo<TypeHotVo> list(TypeHotBo bo, PageQuery pageQuery) {
//        return typeHotService.queryPageList(bo, pageQuery);
//    }
//
//    /**
//     * 导出【请填写功能名称】列表
//     */
//    @SaCheckPermission("system:hot:export")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(TypeHotBo bo, HttpServletResponse response) {
//        List<TypeHotVo> list = typeHotService.queryList(bo);
//        ExcelUtil.exportExcel(list, "【请填写功能名称】", TypeHotVo.class, response);
//    }
//
//    /**
//     * 获取【请填写功能名称】详细信息
//     *
//     * @param typeId 主键
//     */
//    @SaCheckPermission("system:hot:query")
//    @GetMapping("/{typeId}")
//    public R<TypeHotVo> getInfo(@NotNull(message = "主键不能为空")
//                                     @PathVariable String typeId) {
//        return R.ok(typeHotService.queryById(typeId));
//    }
//
//    /**
//     * 新增【请填写功能名称】
//     */
//    @SaCheckPermission("system:hot:add")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
//    @RepeatSubmit()
//    @PostMapping()
//    public R<Void> add(@Validated(AddGroup.class) @RequestBody TypeHotBo bo) {
//        return toAjax(typeHotService.insertByBo(bo));
//    }
//
//    /**
//     * 修改【请填写功能名称】
//     */
//    @SaCheckPermission("system:hot:edit")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
//    @RepeatSubmit()
//    @PutMapping()
//    public R<Void> edit(@Validated(EditGroup.class) @RequestBody TypeHotBo bo) {
//        return toAjax(typeHotService.updateByBo(bo));
//    }
//
//    /**
//     * 删除【请填写功能名称】
//     *
//     * @param typeIds 主键串
//     */
//    @SaCheckPermission("system:hot:remove")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
//    @DeleteMapping("/{typeIds}")
//    public R<Void> remove(@NotEmpty(message = "主键不能为空")
//                          @PathVariable String[] typeIds) {
//        return toAjax(typeHotService.deleteWithValidByIds(List.of(typeIds), true));
//    }
//}
